
Does the application enforce the use of secure passwords. 
-------

**Description:**

When an application does not enforce the use of secure passwords, 
these passwords could easily brute-forced thus compromising the users account.


**Solution:**

The user should be enforced to use secure passwords. This can be done by using a 
password policy. Also known top 1000 passwords should also be forbidden.

	